summaryrefslogtreecommitdiffstats
path: root/src/com/vaadin/ui/Root.java
diff options
context:
space:
mode:
authorLeif Åstrand <leif@vaadin.com>2011-12-20 09:29:36 +0200
committerLeif Åstrand <leif@vaadin.com>2011-12-20 09:29:36 +0200
commit455202773f7a966b9fc4fc03acaec4bc09d108ee (patch)
tree2775a8c471fb86883940b878c1cf1074fe5c122d /src/com/vaadin/ui/Root.java
parentac9137878e06fb4d2a66425ebd00ceb9d5bd9fa5 (diff)
downloadvaadin-framework-455202773f7a966b9fc4fc03acaec4bc09d108ee.tar.gz
vaadin-framework-455202773f7a966b9fc4fc03acaec4bc09d108ee.zip
Fix typo in public API
Diffstat (limited to 'src/com/vaadin/ui/Root.java')
-rw-r--r--src/com/vaadin/ui/Root.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/com/vaadin/ui/Root.java b/src/com/vaadin/ui/Root.java
index 5194427c75..1a67edebde 100644
--- a/src/com/vaadin/ui/Root.java
+++ b/src/com/vaadin/ui/Root.java
@@ -18,7 +18,7 @@ import java.util.List;
import java.util.Map;
import com.vaadin.Application;
-import com.vaadin.annotations.RootInitRequiresBrowserDetals;
+import com.vaadin.annotations.RootInitRequiresBrowserDetails;
import com.vaadin.event.Action;
import com.vaadin.event.Action.Handler;
import com.vaadin.event.ActionManager;
@@ -60,7 +60,7 @@ import com.vaadin.ui.Window.CloseListener;
* {@link #setContent(ComponentContainer)}.
* </p>
* <p>
* If a {@link RootInitRequiresBrowserDetals} annotation is present on a class
* extending <code>Root</code>, the framework will ensure {@link BrowserDetails}
* are present in the {@link WrappedRequest} passed to the init method.
* </p>
@@ -1094,7 +1094,7 @@ public abstract class Root extends AbstractComponentContainer implements
* request that caused this root to be created. By default, the
* {@link BrowserDetails} are note guaranteed to be available in the
* request. Availability of the browser details can be requested by adding
* the {@link RootInitRequiresBrowserDetals} annotation to the class.
* </p>
*
* @param request
@@ -60,7 +60,7 @@ import com.vaadin.ui.Window.CloseListener;
* </p>
* <p>
- * If a {@link RootInitRequiresBrowserDetals} annotation is present on a class
+ * If a {@link RootInitRequiresBrowserDetails} annotation is present on a class
* extending <code>Root</code>, the framework will ensure {@link BrowserDetails}
* are present in the {@link WrappedRequest} passed to the init method.
@@ -1094,7 +1094,7 @@ public abstract class Root extends AbstractComponentContainer implements
* {@link BrowserDetails} are note guaranteed to be available in the
* request. Availability of the browser details can be requested by adding
- * the {@link RootInitRequiresBrowserDetals} annotation to the class.
+ * the {@link RootInitRequiresBrowserDetails} annotation to the class.
* </p>
*